Synonym
=======

.. currentmodule:: pyobo

.. autoclass:: Synonym
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~Synonym.specificity

   .. rubric:: Methods Summary

   .. autosummary::

      ~Synonym.to_obo

   .. rubric:: Attributes Documentation

   .. autoattribute:: specificity

   .. rubric:: Methods Documentation

   .. automethod:: to_obo
